%%%%%%%%%%%%%%%%%%%%%%%
%
%  Created by Lini Zhang "Credit crunches, Individual Heterogeneity  and
%  the Labor wedge"
%  December 27, 2017
%
%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all

%measure labor wedge using the utility function and parameters in my model

lambda=1600; %for quarterly data
beta=0.95082421875^(0.25);
delta=0.06/4;
alpha=0.3;
phi=0.38; %corresponds to tau in the paper
nu=0.9;
sigma=1.5;




t0=1947.5;
t1=2014.75;
t3=1947.5;


data=csvread('ycik.csv',1,1); %real per capita data on y c i k

Y=data(:,1);
C=data(:,2); %per capita C
n=data(:,8); %per capita n, hours
K=data(:,6);
BI=data(:,4);% per capita real private business investment
I=data(:,3);% per capita real private residential investment


num=size(Y);
num=max(num);  time=linspace(t0,t1,num);



%solow residual/measured TFP
%first calculate overall Z 
Z=zeros(num,1);
for t=1:num
    Z(t)=Y(t)*K(t)^(-alpha)*n(t)^(alpha-1);
end
z=log(Z);
[zt,zd]=hptrend(z,lambda);
zd=exp(zd);



%yci
y=log(Y);
c=log(C);
i=log(I); 
bi=log(BI);



[yt,yd]=hptrend(y,lambda);
[ct,cd]=hptrend(c,lambda);
[it,id]=hptrend(i,lambda);
[bit,bid]=hptrend(bi,lambda);


%business cycle component
yd=exp(yd);
cd=exp(cd);
id=exp(id);
bid=exp(bid);

%hours
logn = log(n);
[ht, hd] = hptrend(logn, lambda);
n=exp(hd);

% steady state
zss=mean(zd(5:num-8));
yss=mean(yd(5:num-8)); 
css=mean(cd(5:num-8));
iss=mean(id(5:num-8));
biss=mean(bid(5:num-8));
meanh=mean(n(5:num-8));

t=1; 

yd=yd(t:num);
cd=cd(t:num);
id=id(t:num);
bid=bid(t:num);
n=n(t:num);
zd=zd(t:num);

ynum=max(size(yd));
t2=t3+0.25*(ynum-1);
tvec6=linspace(t3, t2, ynum);


yp=zeros(ynum,1); cp=yp; ip=yp; bip=yp; hourp=yp; zp=yp;
for i=1:ynum
    yp(i)=100*(yd(i,1)-yss)/yss;
    cp(i)=100*(cd(i,1)-css)/css;
    ip(i)=100*(id(i,1)-iss)/iss;
    bip(i)=100*(bid(i,1)-biss)/biss;
    hourp(i,1)=100*(n(i)-meanh)/meanh;
    zp(i)=100*(zd(i)-zss)/zss;
end


num1=221;
num2=269;
num=num2-num1+1;
t0=-5;
t1=7.0;
tvec = linspace(t0,t1,num);

yp = yp(num1:num2);
cp = cp(num1:num2);
hourp = hourp(num1:num2);
zp = zp(num1:num2);
ip = ip(num1:num2);


figure
subplot(221)
hold on
f1=plot(tvec, yp,'k:');
set(f1,'LineWidth',2)
legend('output')


subplot(222)
hold on
f5=plot(tvec, zp,'k:');
set(f5,'LineWidth',2)
legend('measured TFP');


subplot(223)
hold on
f4=plot(tvec, ip,'k:');
set(f4,'LineWidth',2)
legend('investment')


subplot(224)
hold on
f3=plot(tvec, hourp,'k:');
set(f3,'LineWidth',2)
legend('hour')








