%%%%%%%%%%%%%%%%%%%%%%%%
%  Created by Lini Zhang "Credit crunches, Individual Heterogeneity  and
%  the Labor wedge"
%  December 27, 2017%
%%%%%%%%%%%%%%%%%%%%%%%

clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% revised on 11.18.2017 to consider tax wedge%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%measure labor wedge using the utility function and parameters in my model
run tax_wedge 


lambda=1600; %for quarterly data
beta=0.9498242187499999^(0.25); %%%parameters are adopted from model calibration
delta=0.06/4;
alpha=0.3;
phi=0.38; %corresponds to tau in the paper
nu=0.89;
sigma=1.5;


t0=1947.5;  %starting year of the data
t1=2017.5; %end year of the data
t3=2007.75; % starting time of the Great Recession
ts=67; %start from 1964Q1

data=csvread('labor_share.csv',1,1); %real per capita data on y c i k
pm=data(:,3);  % log labor share
pm=log(1-alpha) - pm(1:t); %firm component according to Karabarbounis (2014)

num=size(pm);
num=max(num);  time=linspace(t0,t1,num);



%  Data_Recession contains U.S. recession start and end dates, 1857C2011,
%  discosed by NBER  
%  recession datenum will match with dates tick automatically
load Data_Recessions

datestring=datetime(1947,07,01):calmonths(3):datetime(2017,9,30);
dates=datenum(datestring);




%%%%%%
%%
%% Karabarbounis (2014)
%%
%derive the household component of the labor wedge
hm=lwk-pm;

[pmt,pmb]=hptrend(pm, lambda);
[hmt,hmb]=hptrend(hm, lambda);
%hmt = lwkt - pm;
%hmb = lwkb - pm;

pmp=zeros(num,1); hmp=pmp;

for i=1:num
    pmp(i)=100*(pm(i)-pmt(i))/lwkt(i);
    hmp(i)=100*(hm(i)-hmt(i))/lwkt(i);
end 


%  Data_Recession contains U.S. recession start and end dates, 1857C2011,
%  discosed by NBER  
%  recession datenum will match with dates tick automatically
load Data_Recessions

datestring=datetime(1947,07,01):calmonths(3):datetime(2017,9,30);
dates=datenum(datestring);




figure;
subplot(211)
p1=plot(dates(ts:num-8),yp(ts:num-8),'LineWidth',2);  %plot data series against dates
hold on
p2=plot(dates(ts:num-8),lwkp(ts:num-8),'LineWidth',2,'Color',[.4 0 0]);  %plot data series against dates
h = gca;
h.XTick = dates(ts:12:end-8); %from 5th to end-8, extract a number every 8 counts
datetick('x','yyyy','keepticks')  %Label the x-axis with 4-digit years, preserving the x-axis ticks by using the 'keepticks' option.
xlabel 'Year';
legend('GDP', 'labor wedge')
recessionplot
hBands = recessionplot;
set(hBands,'FaceAlpha',0.1) 
uistack(p1,'top')
uistack(p2,'top')


subplot(212)
p1 = plot(dates(ts:num-8),lwkp(ts:num-8),'LineWidth',2);  %plot data series against date
hold on
p2 = plot(dates(ts:num-8),hmp(ts:num-8),'LineWidth',2,'Color',[.7 0 0]);  %plot data series against dates
hold on
p3 = plot(dates(ts:num-8),pmp(ts:num-8),'LineWidth',2);  %plot data series against dates
h = gca;
h.XTick = dates(ts:12:end-8); %from 5th to end-8, extract a number every 8 counts
datetick('x','yyyy','keepticks')  %Label the x-axis with 4-digit years, preserving the x-axis ticks by using the 'keepticks' option.
xlabel 'Year';
legend('labor wedge (K)', 'MRS component', 'MPL component')
recessionplot
hBands = recessionplot;
set(hBands,'FaceAlpha',0.1)
uistack(p1,'top')
uistack(p2,'top')
uistack(p3,'top')




num1=221;
num2=269;
num=num2-num1+1;
t0=-5;
t1=7.0;
lwkp = lwkp(num1:num2);
hmp = hmp(num1:num2);
pmp = pmp(num1:num2);
tvec = linspace(t0,t1,num);

figure
subplot(221)
f1=plot(tvec, lwkp);
set(f1,'LineWidth',2)
hold on
f2=plot(tvec, hmp,'r--');
set(f2,'LineWidth',2)
hold on
f2=plot(tvec, pmp,'k:');
set(f2,'LineWidth',2)
title('labor wedge decomposition (data)')
legend('labor wedge', 'MRS compnt', 'MPL compnt')

