%%%%%%%%%%%%%%%%%%%%%%%
%
%  Created by Lini Zhang "Credit crunches, Individual Heterogeneity  and
%  the Labor wedge"
%  December 27, 2017
%
%%%%%%%%%%%%%%%%%%%%%%%

clear all

t0=1947.5;  %starting year of the data
t1=1964; %end year of the data
t3=2017.5; % starting time of the Great Recession

num = (t3-t1)*4+1;
data=csvread('taxes.csv',1,1); %real per capita data on y c i k

labortax= data(:,1);
ctax = data(:,2);

taxwedge = (1+ctax)./(1-labortax);




%measure labor wedge using the utility function and parameters in model

lambda=1600; %for quarterly data
beta=0.95082421875^(0.25); %adopted from model calibration
delta=0.06/4;
alpha=0.3;
phi=0.38; %corresponds to tau in the paper
nu=0.9;
sigma=1.5;




t0=1947.5;  %starting year of the data
t1=2017.5; %end year of the data
t3=2007.75; % starting time of the Great Recession


data=csvread('ycik.csv',1,1); %real per capita data on y c i k



Y=data(:,1);
C=data(:,2); %per capita C
n=data(:,8); %per capita n
K=data(:,6);

data2=csvread('taxes.csv',1,1); %real per capita data on y c i k

labortax= data2(:,1);
ctax = data2(:,2);


num=size(Y);
num=max(num); 

t = num;
c = C./(1+ctax(1:t));



%%%%%%%%%%%%%%%%%%%%%%
%
%  efficiency wedge
%
%%%%%%%%%%%%%%%%%%%%%%

logy=log(Y);
logk=log(K);
logn=log(n);

z=logy-(1-alpha)*nu.*logn-alpha*nu.*logk;

[zd,zb]=hptrend(z,lambda);
[yt,yc]=hptrend(logy,lambda);

zb=exp(zb); %business cycle component of z aka solow residual
yc=exp(yc);

%calculate the deviation of wedge from its level in 2007Q4
num2=(t1-t3)*4+1;
time2=linspace(t3,t1,num2);
index07= (t3-t0)*4+1; %time index for 2007Q4
z07=z(index07);

zdev=zeros(num2,1);

for i=1:num2
    zdev(i)=100*(z(index07+i-1)-z07)/z07;
end

%percent deviation from steady state
zss=mean(zb(7:num-8)); 
yss=mean(zb(7:num-8)); 

zp=zeros(num,1); yp=zp;
for i=1:num
    zp(i)=100*(zb(i)-zss)/zss;
    yp(i)=100*(yc(i)-yss)/yss;
end

ydt=yp;
for i=1:num
    ydt(i)=100*(logy(i)-yt(i))/yt(i);
end


%%%%%%%%%%%%%%%%%
%
%   labor wedge
%
%%%%%%%%%%%%%%%%%

tau=zeros(num,1); mrs=tau; mpl=tau;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% measure Labor Wedge using the method in Karabarbounis (2014)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%labor wedge = log(1+labor wedge)= log(MPL)-log (MRS)

lwk=log(Y)-log(n)-log(c) + log(1-n)-log(taxwedge(1:t)) + log(1-alpha) + log(1/phi-1) ;
[lwkt,lwkb]=hptrend(lwk,lambda);

%calculate percent deviation from trend
lwkp=zeros(num,1);
for i=1:num
    lwkp(i)=100*(lwk(i)-lwkt(i))/lwkt(i);
end 




%  Data_Recession contains U.S. recession start and end dates, 1857C2011,
%  discosed by NBER  
%  recession datenum will match with dates tick automatically
load Data_Recessions

datestring=datetime(1947,07,01):calmonths(3):datetime(2017,9,30);
dates=datenum(datestring);



X0=[yp(5:num-8),zp(5:num-8)];

figure;
subplot(211)
plot(dates(5:num-8),X0,'LineWidth',2);  %plot data series against dates
h = gca;
h.XTick = dates(5:12:end-8); %from 5th to end-8, extract a number every 8 counts
datetick('x','yyyy','keepticks')  %Label the x-axis with 4-digit years, preserving the x-axis ticks by using the 'keepticks' option.
xlabel 'Year';
legend('GDP','TFP (efficiency wedge)')
recessionplot
hBands = recessionplot;
set(hBands,'FaceAlpha',0.1)
 
 
subplot(212)
plot(dates(5:num-8),yp(5:num-8),'LineWidth',2);  %plot data series against dates
hold on
plot(dates(5:num-8),lwkp(5:num-8),'LineWidth',2,'Color',[.4 0 0]);  %plot data series against dates
h = gca;
h.XTick = dates(5:12:end-8); %from 5th to end-8, extract a number every 8 counts
datetick('x','yyyy','keepticks')  %Label the x-axis with 4-digit years, preserving the x-axis ticks by using the 'keepticks' option.
xlabel 'Year';
legend('GDP', 'labor wedge(k)')
recessionplot
hBands = recessionplot;
set(hBands,'FaceAlpha',0.1) 


t0=1947.5;  %starting year of the data
t1=1964; %end year of the data
t3=2017.5; % starting time of the Great Recession

num = (t3-t1)*4+1;
time = linspace(t1,t3,num);
num1 = 67;
num2 = 281;

figure
%f1=plot(time,taxwedge(num1:num2)');
p1=plot(dates,taxwedge','LineWidth',2);
hold on
title('tax wedge')
hold on
h = gca;
h.XTick = dates(1:12:end); %from 5th to end-8, extract a number every 8 counts
datetick('x','yy','keepticks')  %Label the x-axis with 4-digit years, preserving the x-axis ticks by using the 'keepticks' option.
xlabel 'Year';
recessionplot
hBands = recessionplot;
set(hBands,'FaceAlpha',0.1) 
uistack(p1,'top')




  